==> blender-2.26.tar.bz2: blender-2.26/source/blender/readstreamglue/intern/BLO_keyStorePrivate.h <==
/**
 * $Id: BLO_keyStorePrivate.h,v 1.5 2002/12/27 13:10:32 mein Exp $
 *
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
 */

#ifndef BLO_KEYSTOREPRIVATE_H
#define BLO_KEYSTOREPRIVATE_H

#ifdef __cplusplus
extern "C" {
#endif

#include "blenkey.h"

// TODO this must be made external in key.h
#define MAXBYTEDATABLOCK 1000

struct keyStoreStruct {
	UserStruct keyUserStruct;

	byte *privKey;
	int privKeyLen;

	byte *pubKey;
	int pubKeyLen;

	byte ByteChecks[MAXBYTEDATABLOCK];

	byte *PythonCode;
	int PythonCodeLen;
};

#ifdef __cplusplus
}
#endif

#endif /* BLO_KEYSTOREPRIVATE_H */

==> blender-2.28a.tar.bz2: blender-2.28a/source/blender/readstreamglue/intern/BLO_keyStorePrivate.h <==
/**
 * $Id: BLO_keyStorePrivate.h,v 1.6 2003/05/30 15:06:43 sirdude Exp $
 *
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
 */

#ifndef BLO_KEYSTOREPRIVATE_H
#define BLO_KEYSTOREPRIVATE_H

#ifdef __cplusplus
extern "C" {
#endif

// TODO this must be made external in key.h
#define MAXBYTEDATABLOCK 1000

struct keyStoreStruct {
	UserStruct keyUserStruct;

	unsigned char *privKey;
	int privKeyLen;

	unsigned char *pubKey;
	int pubKeyLen;

	unsigned char ByteChecks[MAXBYTEDATABLOCK];

	unsigned char *PythonCode;
	int PythonCodeLen;
};

#ifdef __cplusplus
}
#endif

#endif /* BLO_KEYSTOREPRIVATE_H */
